@@ -1,4 +1,4 @@
-/* $Id: display_plugin.c 21493 2006-05-04 21:26:41Z benny $ */
+/* $Id: display_plugin.c 23706 2006-11-05 09:16:37Z olivier $ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -742,12 +742,10 @@ run_dialog (McsPlugin * plugin)
     gtk_box_pack_start (GTK_BOX (hbox), align, FALSE, TRUE, 0);
 
     /* resolution settings */
-    frame = xfce_framebox_new (_("Resolution"), TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
-
     vbox = gtk_vbox_new (FALSE, BORDER);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
-    xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
+    frame = xfce_create_framebox_with_content (_("Resolution"), vbox);
+    gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
 
     /* create the surrounding scrolled window */
     scrollwin = gtk_scrolled_window_new (NULL, NULL);
@@ -863,12 +861,10 @@ run_dialog (McsPlugin * plugin)
     g_object_unref (G_OBJECT (store));
 
     /* gamma settings */
-    frame = xfce_framebox_new (_("Gamma correction"), TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
-
     vbox = gtk_vbox_new (FALSE, BORDER);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
-    xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
+    frame = xfce_create_framebox_with_content (_("Gamma correction"), vbox);
+    gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
 
     /* */
     table = gtk_table_new (3, 3, FALSE);
