@@ -699,16 +699,15 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
     gtk_widget_show(dialog->themes_notebook);
     gtk_box_pack_start(GTK_BOX(dialog->hbox1), dialog->themes_notebook, TRUE, TRUE, 0);
 
-    dialog->frame1 = xfce_framebox_new(NULL, FALSE);
+    dialog->vbox2 = gtk_vbox_new(FALSE, 5);
+    gtk_widget_show(dialog->vbox2);
+
+    dialog->frame1 = xfce_create_framebox_with_content(NULL, dialog->vbox2);
     gtk_widget_show(dialog->frame1);
     dialog->theme_label = gtk_label_new_with_mnemonic(_("_Theme"));
     gtk_widget_show(dialog->theme_label);
     gtk_notebook_append_page(GTK_NOTEBOOK(dialog->themes_notebook), dialog->frame1, dialog->theme_label);
 
-    dialog->vbox2 = gtk_vbox_new(FALSE, 5);
-    gtk_widget_show(dialog->vbox2);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->frame1), dialog->vbox2);
-
     dialog->hbox2 = gtk_hbox_new(FALSE, 8);
     gtk_widget_show(dialog->hbox2);
     gtk_box_pack_start(GTK_BOX(dialog->vbox2), dialog->hbox2, TRUE, TRUE, 0);
@@ -723,16 +722,15 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
     gtk_container_add(GTK_CONTAINER(dialog->theme_swindow), dialog->theme_treeview);
     gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(dialog->theme_treeview), FALSE);
 
-    dialog->frame4 = xfce_framebox_new(NULL, FALSE);
+    dialog->vbox4 = gtk_vbox_new(FALSE, 5);
+    gtk_widget_show(dialog->vbox4);
+
+    dialog->frame4 = xfce_create_framebox_with_content (NULL, dialog->vbox4);
     gtk_widget_show(dialog->frame4);
     dialog->icon_theme_label = gtk_label_new_with_mnemonic(_("_Icon Theme"));
     gtk_widget_show(dialog->icon_theme_label);
     gtk_notebook_append_page(GTK_NOTEBOOK(dialog->themes_notebook), dialog->frame4, dialog->icon_theme_label);
 
-    dialog->vbox4 = gtk_vbox_new(FALSE, 5);
-    gtk_widget_show(dialog->vbox4);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->frame4), dialog->vbox4);
-
     dialog->hbox3 = gtk_hbox_new(FALSE, 8);
     gtk_widget_show(dialog->hbox3);
     gtk_box_pack_start(GTK_BOX(dialog->vbox4), dialog->hbox3, TRUE, TRUE, 0);
@@ -751,22 +749,20 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
     gtk_widget_show(dialog->vbox3);
     gtk_box_pack_start(GTK_BOX(dialog->hbox1), dialog->vbox3, TRUE, TRUE, 0);
 
-    dialog->frame2 = xfce_framebox_new(_("Font"), TRUE);
-    gtk_widget_show(dialog->frame2);
-    gtk_box_pack_start(GTK_BOX(dialog->vbox3), dialog->frame2, TRUE, FALSE, 0);
-
     dialog->button3 = gtk_button_new();
     gtk_button_set_label(GTK_BUTTON(dialog->button3), current_font);
     gtk_widget_show(dialog->button3);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->frame2), dialog->button3);
 
-    dialog->frame3 = xfce_framebox_new(_("Toolbar Style"), TRUE);
-    gtk_widget_show(dialog->frame3);
-    gtk_box_pack_start(GTK_BOX(dialog->vbox3), dialog->frame3, TRUE, FALSE, 0);
+    dialog->frame2 = xfce_create_framebox_with_content (_("Font"), dialog->button3);
+    gtk_widget_show(dialog->frame2);
+    gtk_box_pack_start(GTK_BOX(dialog->vbox3), dialog->frame2, TRUE, FALSE, 0);
 
     dialog->optionmenu1 = gtk_combo_box_new_text();
     gtk_widget_show(dialog->optionmenu1);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->frame3), dialog->optionmenu1);
+
+    dialog->frame3 = xfce_create_framebox_with_content (_("Toolbar Style"), dialog->optionmenu1);
+    gtk_widget_show(dialog->frame3);
+    gtk_box_pack_start(GTK_BOX(dialog->vbox3), dialog->frame3, TRUE, FALSE, 0);
 
     gtk_combo_box_append_text(GTK_COMBO_BOX(dialog->optionmenu1), _("Icons"));
     gtk_combo_box_append_text(GTK_COMBO_BOX(dialog->optionmenu1), _("Text"));
@@ -775,25 +771,23 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
 
     combo_box_set_active(GTK_COMBO_BOX(dialog->optionmenu1), icons_styles, current_toolbar_style, 0);
 
-    dialog->frame5 = xfce_framebox_new(_("Menu Accelerators"), TRUE);
-    gtk_widget_show(dialog->frame5);
-    gtk_box_pack_start(GTK_BOX(dialog->vbox3), dialog->frame5, TRUE, FALSE, 0);
-
     dialog->accel_checkbox = gtk_check_button_new_with_label(_("Editable menu accelerators"));
     gtk_widget_show(dialog->accel_checkbox);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->frame5), dialog->accel_checkbox);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->accel_checkbox), (gboolean) can_change_accel);    
 
+    dialog->frame5 = xfce_create_framebox_with_content (_("Menu Accelerators"), dialog->accel_checkbox);
+    gtk_widget_show(dialog->frame5);
+    gtk_box_pack_start(GTK_BOX(dialog->vbox3), dialog->frame5, TRUE, FALSE, 0);
+
     /**
      ** XXX move this to a separate notebook tab?
      **/
-    dialog->aa_framebox = xfce_framebox_new(_("Font Rendering"), TRUE);
-    gtk_widget_show(dialog->aa_framebox);
-    gtk_box_pack_start(GTK_BOX(dialog->dialog_vbox1), dialog->aa_framebox, TRUE, FALSE, 5);
-
     dialog->aa_table = gtk_table_new(2, 3, FALSE);
     gtk_widget_show(dialog->aa_table);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->aa_framebox), dialog->aa_table);
+
+    dialog->aa_framebox = xfce_create_framebox_with_content (_("Font Rendering"), dialog->aa_table);
+    gtk_widget_show(dialog->aa_framebox);
+    gtk_box_pack_start(GTK_BOX(dialog->dialog_vbox1), dialog->aa_framebox, TRUE, FALSE, 5);
 
     dialog->aa_checkbox1 = gtk_check_button_new_with_label(_("Use anti-aliasing for fonts"));
     gtk_widget_show(dialog->aa_checkbox1);
